==> webStore_2.8.2_estable.zip: comunes/widgets/banner.php <==
<?php

//---------------------------------------------------------------------------------------------------------
// 25/marzo/2015
// Versi?n 1.0 Widget que utilizaremos para mostrar banners
//---------------------------------------------------------------------------------------------------------



function widget_banner() {
    include("comunes/globals.php");
    //Aqu? definimos una serie de par?metros que necesitamos
    $funcion_por_defecto = "banner";
    $parametros_por_defecto = array();
    $parametros_recibidos = func_get_args();
    if (count($parametros_recibidos) == 0) {
        $parametros_recibidos[0] = $funcion_por_defecto;
    } else {
        if (($parametros_recibidos[0] == "") || ($parametros_recibidos[0] == NULL)) {
            $parametros_recibidos[0] = $funcion_por_defecto;
        }
    }
    $parametros_recibidos = mezcla_array_parametros($parametros_por_defecto, $parametros_recibidos);
    $retorno = false;
    //Si entre los par?metros recibidos, tenemos el nombre de la funci?n continuamos
    if (count($parametros_recibidos) > 0) {
        //Recogemos el nombre de la funci?n de entre el resto de par?metros
        $nombre_funcion = $parametros_recibidos[0];
        //Quitamos el primer elemento de los par?metros, pues es el nombre de la funci?n
        $parametros_recibidos = array_slice($parametros_recibidos, 1);
        //Si la funci?n existe la ejecutamos
        if (function_exists($nombre_funcion)) {
			//var_dump($parametros_recibidos);
            $retorno = call_user_func_array($nombre_funcion, $parametros_recibidos);
        }
    }
    return($retorno);
}

function banner($fichero = "banner", $condicion = "", $activo = 1, $capa_contenedora = true, $background = false) {
	//echo("$fichero, $condicion, $activo, $capa_contenedora, $background <br />\n");
    include("comunes/globals.php");
    $ocultarCabecera = false;
    if (($fichero != NULL) && (is_a($fichero, "OpcionesWidget"))) {
        $opciones = $fichero;
        $fichero = "banner";
        $condicion = "";
        $activo = 1;
        $capa_contenedora = true;
        $background = false;
        if (is_a($opciones, 'OpcionesWidget')) {
            $fichero = ($opciones->configuracion->fichero != NULL) ? $opciones->configuracion->fichero : $fichero;
            $condicion = ($opciones->configuracion->condicion != NULL) ? $opciones->configuracion->condicion : $condicion;
            $activo = ($opciones->configuracion->activo != NULL) ? $opciones->configuracion->activo : $activo;
            $capa_contenedora = ($opciones->configuracion->capa_contenedora != NULL) ? $opciones->capa_contenedora->$capa_contenedora : $fichero;
            $background = ($opciones->configuracion->background != NULL) ? $opciones->configuracion->background : $background;
            $ocultarCabecera = ($opciones->configuracion->ocultarCabecera != NULL) ? $opciones->configuracion->ocultarCabecera : $ocultarCabecera;
        }
    }
    //$banner_a_mostrar = array();
    $banner_a_mostrar = NULL;
    $idioma = Sesion::get("idioma");
    $idioma = ($idioma != NULL) ? $idioma : Shop::$configuracion->idioma;

    //Vamos a cargar los banner disponibles
    $sentencia_sql = "SELECT codigo
					  FROM banner 
					  WHERE condicion = '" . $condicion . "' AND activo = " . $activo . " AND idioma ='" . $idioma . "'
					  ORDER BY orden ASC";
	//echo("$sentencia_sql<br />\n");
    if ($conexionBD) {
        if ($resultado = mysqli_query($conexionBD, $sentencia_sql)) {
            /* if(mysqli_num_rows($resultado) == 0){
              $sentencia_sql = "SELECT codigo
              FROM banner
              WHERE condicion = '". $condicion . "' AND activo = ". $activo ." AND idioma ='".Shop::$configuracion->idioma."'
              ORDER BY orden ASC";
              $resultado = mysqli_query($conexionBD, $sentencia_sql);
              }
             */
            while ($fila = mysqli_fetch_array($resultado)) {
                if ($capa_contenedora) {
                    if ($ocultarCabecera) {
                        ?>

                        <div class="<?= (__FUNCTION__); ?>">
                            <?php
                        }
                    }
                    $banner_a_mostrar = new Banner($fila["codigo"]);
                    $ruta = Theme::findFile($fichero . ".php");
                    if ($ruta != NULL) {
                        include($ruta);
                    }
                    //$banner_a_mostrar[count($banner_a_mostrar)] = new Banner($fila["codigo"]);
                    unset($banner_a_mostrar);
                    if ($capa_contenedora) {
                        if ($ocultarCabecera) {
                            ?>
                        </div>
                        <?php
                    }
                    ?>
                    <?php
                }
            }
        }
    }
    return(true);
}

function adminShowImageList($opciones = NULl){
	//Inicializamos las variables
	$ruta_actual = '';	//Array con la ruta actual hasta la foto
	$rufaFichero = 'simple_img.php';
	$rutaFicheroUpDown = 'fotos_abrir_carpeta.php';
	$rutaFicheroCrearDirectorio = 'fotos_crear_carpeta.php';
	$clase_x_defecto = 'row el-element-overlay';
	$script_x_defecto = '$(\'.image-popup-vertical-fit\').magnificPopup({
	type: \'image\',
	closeOnContentClick: true,
	mainClass: \'mfp-img-mobile\',
	image: {
		verticalFit: true
	}
	
});';
	//Nos aseguramos de que haaya un "opcionesWidget"
	$opciones = (is_a($opciones, 'OpcionesWidget')) ? $opciones : new OpcionesWidget();
	//Recogemos las variables de opciones
	$ruta_actual = ($opciones->configuracion->ruta_actual != null) ? $opciones->configuracion->ruta_actual : $ruta_actual;
	$rufaFichero = ($opciones->configuracion->rufaFichero != null) ? $opciones->configuracion->rufaFichero : $rufaFichero;
	$rutaFicheroUpDown = ($opciones->configuracion->rutaFicheroUpDown != null) ? $opciones->configuracion->rutaFicheroUpDown : $rutaFicheroUpDown;
	$rutaFicheroCrearDirectorio = ($opciones->configuracion->rutaFicheroCrearDirectorio != null) ? $opciones->configuracion->rutaFicheroCrearDirectorio : $rutaFicheroCrearDirectorio;
	$clase_x_defecto = ($opciones->configuracion->clase_x_defecto != null) ? $opciones->configuracion->clase_x_defecto : $clase_x_defecto;
	$script_x_defecto = ($opciones->configuracion->script_x_defecto != null) ? $opciones->configuracion->script_x_defecto : $script_x_defecto;
	$configuracionWidget = base64_encode(serialize(array(
		'widget' => 'banner',
		'function' => __FUNCTION__,
		'opciones' => $opciones
	)));
	if ($clase_x_defecto != ''){
		$clase_x_defecto = 'class="' . $clase_x_defecto . '"';
	}
	
	//Ojo, la ruta actual, aunq nos la manden, la que tiene prioridad SIEMPRE es la de la sesión:
	$ruta_actual = Sesion::get('ruta_img_actual', $ruta_actual);
	//La ruta actual NUNCA será '/':
	$ruta_actual = ($ruta_actual == '/') ? '' : $ruta_actual;
	$ruta_real = realpath(_WS_UPLOAD_IMAGES_DIR_) . '/' . $ruta_actual;
	//Ahora vamos a tener en cuenta que es posible que esa ruta esté mal:
	//echo("ruta_actual: $ruta_actual\n");
	//echo("ruta_real: $ruta_real\n");
	if (!is_dir($ruta_real)){
		//La ruta almacenada en la sesión no nos sirve:
		Sesion::remove('ruta_img_actual');
		$ruta_actual = '';
		$ruta_real = realpath(_WS_UPLOAD_IMAGES_DIR_) . DIRECTORY_SEPARATOR . $ruta_actual;
	}
	
	//Necesitamos cambiar el imput del selector de ficheros:
	?>
	<div  data-configuration="<?=$configuracionWidget;?>" data-update="img_list_change">

	
	
<script>
//Vamos a controlar si jquery está o no cargado:
try {
	//var test = Dropzone.ERROR;
	//Si seguimos por aquí, es pq está dropzone cargado
	$('#zonaSubida').addClass('dropzone');
	var myDropzone = new Dropzone("#zonaSubida", { url: "<?=Shop::$configuracion->url;?>upload", dictDefaultMessage:'<?=traducir('Haga click aquí para selecionar los ficheros o arrástrelos con el ratón');?>'});	
	myDropzone.on("queuecomplete", function(file) {
		WS_data_update('','',{},'=\'img_list_change\'',function(data){});
	});
}
catch(err) {
	document.addEventListener('WSLE', function(event) {
		//$('.dz-message span').html('<?=traducir('Haga click aquí para selecionar los ficheros o arrástrelos con el ratón');?>');
		$('#zonaSubida').addClass('dropzone');
		
		var myDropzone = new Dropzone("#zonaSubida", { url: "<?=Shop::$configuracion->url;?>upload", dictDefaultMessage:'<?=traducir('Haga click aquí para selecionar los ficheros o arrástrelos con el ratón');?>'});	
		myDropzone.on("queuecomplete", function(file) {
			WS_data_update('','',{},'=\'img_list_change\'',function(data){});
		});
	});
}
</script>
<form action="<?=Shop::$configuracion->url;?>upload" class="" id="zonaSubida">
<?php
if ($ruta_actual != ''){
?>
<input type="hidden" name="ruta_actual" value="<?=$ruta_actual;?>">
<?php
}
?>
</form>	
	
	
	
	<nav aria-label="breadcrumb">
		<ol class="breadcrumb">
			<li class="breadcrumb-item"><a href="javascript:void(0);" onclick="
			var sendData = { 'ruta_img_actual' : ''};
			WS_data_update(
				'Sesion',
				'set',
				sendData,
				'=\'img_list_change\'',
				function(data){}
			);
			"><?=traducir('Imágenes');?></a></li>
	<?php
		$lista = explode(DIRECTORY_SEPARATOR, $ruta_actual );
		$acumulado = '';
		foreach($lista as $clave => $valor){
			if ($clave < (count($lista) - 1)){
				if (trim($valor) != ''){
					$acumulado .= '/' . $valor;
	?>
			<li class="breadcrumb-item"><a href="javascript:void(0);" onclick="
			var sendData = { 'ruta_img_actual' : '<?=$acumulado;?>'};
			WS_data_update(
				'Sesion',
				'set',
				sendData,
				'=\'img_list_change\'',
				function(data){}
			);
			"><?=$valor;?></a></li>
	<?php
				}
			}else{
	?>
			<li class="breadcrumb-item active" aria-current="page"><?=$valor;?></li>
	<?php			
			}
		}
	?>
		</ol>
	</nav>
	<div <?=$clase_x_defecto;?>>
	<?php
	//Aquí viene la lógica de la función:
		//$ruta_real = realpath(_WS_UPLOAD_IMAGES_DIR_) . DIRECTORY_SEPARATOR . $ruta_actual;
		//Vamos a empezar por mostrar los directorios que tenemos ahora mismo:
		if (is_dir($ruta_real)){
			//Ya estamos colocados en el directorio actual. Vamos a sacar primero las carpetas:
			if ( ($ruta_actual != '') && ($rutaFicheroUpDown != '') ){
				//Hay que añadir un icono de "volver", vamos a calcular la ruta:
				$ruta_actual_array = $ruta_actual;
				$ruta_actual_array = dirname('/' . $ruta_actual_array);	//Nos aseguramos de que SIEMPRE tenga una /
				$ruta_actual_array = ($ruta_actual_array == '.') ? '' : $ruta_actual_array;	//Si es un punto es como si no fuese nada ;)
				$ruta_actual_array .= ((strlen($ruta_actual_array) > 1) ? '/' : '');
				Theme::include_file($rutaFicheroUpDown, ((strlen($ruta_actual_array) > 1) ? '/' : '') . $ruta_actual_array, traducir('Atrás'));
				//Ya tenemos nuestro botón de subir un nivel. Ahora necesitamos 
			}
			//Vamos a mostrar las carpetas que hay:
			$lista_ficheros_directorios = scandir($ruta_real);
			foreach($lista_ficheros_directorios as $clave => $nombreDir){
				if (is_dir($ruta_real . DIRECTORY_SEPARATOR . $nombreDir)){
					if( ($nombreDir != '.') && ($nombreDir != '..') ){
						$ruta_real_carpeta = realpath($ruta_real . DIRECTORY_SEPARATOR . $nombreDir);
						$ruta_relativa_carpeta = str_replace(realpath(_WS_UPLOAD_IMAGES_DIR_), '', $ruta_real_carpeta);
						Theme::include_file($rutaFicheroUpDown, $ruta_actual . ($ruta_actual != '' ? DIRECTORY_SEPARATOR : '') . $nombreDir, $nombreDir, 'mdi mdi-folder-multiple', $ruta_relativa_carpeta);
					}
				}
			}
			if ($rutaFicheroCrearDirectorio != ''){
				//Por último, siempre vamos a crear la carpeta:
				Theme::include_file($rutaFicheroCrearDirectorio, $ruta_actual);
			}

			if ($rufaFichero != ''){
				$extensions = '{jpg,JPG,gif,GIF,png,PNG,bmp,BMP}';
				//Vamos a recorrer la carpeta de imagenes
				$filtro = $ruta_real . '/*.' . $extensions;
				$images = glob($filtro, GLOB_BRACE);
				//var_dump($images);
				if ($images !== false){
					foreach($images as $kew => $value){
						$img_name = _WS_UPLOAD_IMAGES_DIR_ . $ruta_actual . (substr($ruta_actual,-1) != DIRECTORY_SEPARATOR ? DIRECTORY_SEPARATOR : '') . basename($value);
						Theme::include_file($rufaFichero, $img_name);
					}
				}
			}
		}else{
			
		}
		if ($script_x_defecto != ''){
?>
<script>
try {
 <?=$script_x_defecto;?>;
}
catch(err) {
}
</script>
<?php
		}
	?>
	</div>
	</div>
	<?php
}

?>

==> webStore_2.8.9.003_estable.zip: comunes/widgets/banner.php <==
<?php

//---------------------------------------------------------------------------------------------------------
// 25/marzo/2015
// Versi?n 1.0 Widget que utilizaremos para mostrar banners
//---------------------------------------------------------------------------------------------------------



function widget_banner() {
    include("comunes/globals.php");
    //Aqu? definimos una serie de par?metros que necesitamos
    $funcion_por_defecto = "banner";
    $parametros_por_defecto = array();
    $parametros_recibidos = func_get_args();
    if (count($parametros_recibidos) == 0) {
        $parametros_recibidos[0] = $funcion_por_defecto;
    } else {
        if (($parametros_recibidos[0] == "") || ($parametros_recibidos[0] == NULL)) {
            $parametros_recibidos[0] = $funcion_por_defecto;
        }
    }
    $parametros_recibidos = mezcla_array_parametros($parametros_por_defecto, $parametros_recibidos);
    $retorno = false;
    //Si entre los par?metros recibidos, tenemos el nombre de la funci?n continuamos
    if (count($parametros_recibidos) > 0) {
        //Recogemos el nombre de la funci?n de entre el resto de par?metros
        $nombre_funcion = $parametros_recibidos[0];
        //Quitamos el primer elemento de los par?metros, pues es el nombre de la funci?n
        $parametros_recibidos = array_slice($parametros_recibidos, 1);
        //Si la funci?n existe la ejecutamos
        if (function_exists($nombre_funcion)) {
			//var_dump($parametros_recibidos);
            $retorno = call_user_func_array($nombre_funcion, $parametros_recibidos);
        }
    }
    return($retorno);
}

function banner($fichero = "banner", $condicion = "", $activo = 1, $capa_contenedora = true, $background = false) {
	//echo("$fichero, $condicion, $activo, $capa_contenedora, $background <br />\n");
    include("comunes/globals.php");
    $ocultarCabecera = false;
    if (($fichero != NULL) && (is_a($fichero, "OpcionesWidget"))) {
        $opciones = $fichero;
        $fichero = "banner";
        $condicion = "";
        $activo = 1;
        $capa_contenedora = true;
        $background = false;
        if (is_a($opciones, 'OpcionesWidget')) {
            $fichero = ($opciones->configuracion->fichero != NULL) ? $opciones->configuracion->fichero : $fichero;
            $condicion = ($opciones->configuracion->condicion != NULL) ? $opciones->configuracion->condicion : $condicion;
            $activo = ($opciones->configuracion->activo != NULL) ? $opciones->configuracion->activo : $activo;
            $capa_contenedora = ($opciones->configuracion->capa_contenedora != NULL) ? $opciones->capa_contenedora->$capa_contenedora : $fichero;
            $background = ($opciones->configuracion->background != NULL) ? $opciones->configuracion->background : $background;
            $ocultarCabecera = ($opciones->configuracion->ocultarCabecera != NULL) ? $opciones->configuracion->ocultarCabecera : $ocultarCabecera;
        }
    }
	//Modificado por Pedro el 07/Octubre/2019 ==> Vamos a cargar los banners usando "ListaBanner" en vez de una select:
	$listaBanners = new ListaBanner($condicion, $activo);
	
	foreach($listaBanners->getList() as $clave => $banner_a_mostrar){
		if ($capa_contenedora) {
			if ($ocultarCabecera) {
				?>

				<div class="<?= (__FUNCTION__); ?>">
					<?php
				}
			}
			$ruta = Theme::findFile($fichero . ".php");
			if ($ruta != NULL) {
				include($ruta);
			}
			if ($capa_contenedora) {
				if ($ocultarCabecera) {
					?>
				</div>
				<?php
			}
			?>
			<?php
		}
	}
    return(true);
}

function adminShowImageList($opciones = NULl){
	//Inicializamos las variables
	$ruta_actual = '';	//Array con la ruta actual hasta la foto
	$rufaFichero = 'simple_img.php';
	$rutaFicheroUpDown = 'fotos_abrir_carpeta.php';
	$rutaFicheroCrearDirectorio = 'fotos_crear_carpeta.php';
	$clase_x_defecto = 'row el-element-overlay';
	$script_x_defecto = '$(\'.image-popup-vertical-fit\').magnificPopup({
	type: \'image\',
	closeOnContentClick: true,
	mainClass: \'mfp-img-mobile\',
	image: {
		verticalFit: true
	}
	
});';
	//Nos aseguramos de que haaya un "opcionesWidget"
	$opciones = (is_a($opciones, 'OpcionesWidget')) ? $opciones : new OpcionesWidget();
	//Recogemos las variables de opciones
	$ruta_actual = ($opciones->configuracion->ruta_actual != null) ? $opciones->configuracion->ruta_actual : $ruta_actual;
	$rufaFichero = ($opciones->configuracion->rufaFichero != null) ? $opciones->configuracion->rufaFichero : $rufaFichero;
	$rutaFicheroUpDown = ($opciones->configuracion->rutaFicheroUpDown != null) ? $opciones->configuracion->rutaFicheroUpDown : $rutaFicheroUpDown;
	$rutaFicheroCrearDirectorio = ($opciones->configuracion->rutaFicheroCrearDirectorio != null) ? $opciones->configuracion->rutaFicheroCrearDirectorio : $rutaFicheroCrearDirectorio;
	$clase_x_defecto = ($opciones->configuracion->clase_x_defecto != null) ? $opciones->configuracion->clase_x_defecto : $clase_x_defecto;
	$script_x_defecto = ($opciones->configuracion->script_x_defecto != null) ? $opciones->configuracion->script_x_defecto : $script_x_defecto;
	$configuracionWidget = base64_encode(serialize(array(
		'widget' => 'banner',
		'function' => __FUNCTION__,
		'opciones' => $opciones
	)));
	if ($clase_x_defecto != ''){
		$clase_x_defecto = 'class="' . $clase_x_defecto . '"';
	}
	
	//Ojo, la ruta actual, aunq nos la manden, la que tiene prioridad SIEMPRE es la de la sesión:
	$ruta_actual = Sesion::get('ruta_img_actual', $ruta_actual);
	//La ruta actual NUNCA será '/':
	$ruta_actual = ($ruta_actual == '/') ? '' : $ruta_actual;
	$ruta_real = realpath(_WS_UPLOAD_IMAGES_DIR_) . '/' . $ruta_actual;
	//Ahora vamos a tener en cuenta que es posible que esa ruta esté mal:
	//echo("ruta_actual: $ruta_actual\n");
	//echo("ruta_real: $ruta_real\n");
	if (!is_dir($ruta_real)){
		//La ruta almacenada en la sesión no nos sirve:
		Sesion::remove('ruta_img_actual');
		$ruta_actual = '';
		$ruta_real = realpath(_WS_UPLOAD_IMAGES_DIR_) . DIRECTORY_SEPARATOR . $ruta_actual;
	}
	
	//Necesitamos cambiar el imput del selector de ficheros:
	?>
	<div  data-configuration="<?=$configuracionWidget;?>" data-update="img_list_change">

	
	
<script>
//Vamos a controlar si jquery está o no cargado:
try {
	//var test = Dropzone.ERROR;
	//Si seguimos por aquí, es pq está dropzone cargado
	$('#zonaSubida').addClass('dropzone');
	var myDropzone = new Dropzone("#zonaSubida", { url: "<?=Shop::$configuracion->url;?>upload", dictDefaultMessage:'<?=traducir('Haga click aquí para selecionar los ficheros o arrástrelos con el ratón');?>'});	
	myDropzone.on("queuecomplete", function(file) {
		WS_data_update('','',{},'=\'img_list_change\'',function(data){});
	});
}
catch(err) {
	document.addEventListener('WSLE', function(event) {
		//$('.dz-message span').html('<?=traducir('Haga click aquí para selecionar los ficheros o arrástrelos con el ratón');?>');
		$('#zonaSubida').addClass('dropzone');
		
		var myDropzone = new Dropzone("#zonaSubida", { url: "<?=Shop::$configuracion->url;?>upload", dictDefaultMessage:'<?=traducir('Haga click aquí para selecionar los ficheros o arrástrelos con el ratón');?>'});	
		myDropzone.on("queuecomplete", function(file) {
			WS_data_update('','',{},'=\'img_list_change\'',function(data){});
		});
	});
}
</script>
<form action="<?=Shop::$configuracion->url;?>upload" class="" id="zonaSubida">
<?php
if ($ruta_actual != ''){
?>
<input type="hidden" name="ruta_actual" value="<?=$ruta_actual;?>">
<?php
}
?>
</form>	
	
	
	
	<nav aria-label="breadcrumb">
		<ol class="breadcrumb">
			<li class="breadcrumb-item"><a href="javascript:void(0);" onclick="
			var sendData = { 'ruta_img_actual' : ''};
			WS_data_update(
				'Sesion',
				'set',
				sendData,
				'=\'img_list_change\'',
				function(data){}
			);
			"><?=traducir('Imágenes');?></a></li>
	<?php
		$lista = explode(DIRECTORY_SEPARATOR, $ruta_actual );
		$acumulado = '';
		foreach($lista as $clave => $valor){
			if ($clave < (count($lista) - 1)){
				if (trim($valor) != ''){
					$acumulado .= '/' . $valor;
	?>
			<li class="breadcrumb-item"><a href="javascript:void(0);" onclick="
			var sendData = { 'ruta_img_actual' : '<?=$acumulado;?>'};
			WS_data_update(
				'Sesion',
				'set',
				sendData,
				'=\'img_list_change\'',
				function(data){}
			);
			"><?=$valor;?></a></li>
	<?php
				}
			}else{
	?>
			<li class="breadcrumb-item active" aria-current="page"><?=$valor;?></li>
	<?php			
			}
		}
	?>
		</ol>
	</nav>
	<div <?=$clase_x_defecto;?>>
	<?php
	//Aquí viene la lógica de la función:
		//$ruta_real = realpath(_WS_UPLOAD_IMAGES_DIR_) . DIRECTORY_SEPARATOR . $ruta_actual;
		//Vamos a empezar por mostrar los directorios que tenemos ahora mismo:
		if (is_dir($ruta_real)){
			//Ya estamos colocados en el directorio actual. Vamos a sacar primero las carpetas:
			if ( ($ruta_actual != '') && ($rutaFicheroUpDown != '') ){
				//Hay que añadir un icono de "volver", vamos a calcular la ruta:
				$ruta_actual_array = $ruta_actual;
				$ruta_actual_array = dirname('/' . $ruta_actual_array);	//Nos aseguramos de que SIEMPRE tenga una /
				$ruta_actual_array = ($ruta_actual_array == '.') ? '' : $ruta_actual_array;	//Si es un punto es como si no fuese nada ;)
				$ruta_actual_array .= ((strlen($ruta_actual_array) > 1) ? '/' : '');
				Theme::include_file($rutaFicheroUpDown, ((strlen($ruta_actual_array) > 1) ? '/' : '') . $ruta_actual_array, traducir('Atrás'));
				//Ya tenemos nuestro botón de subir un nivel. Ahora necesitamos 
			}
			//Vamos a mostrar las carpetas que hay:
			$lista_ficheros_directorios = scandir($ruta_real);
			foreach($lista_ficheros_directorios as $clave => $nombreDir){
				if (is_dir($ruta_real . DIRECTORY_SEPARATOR . $nombreDir)){
					if( ($nombreDir != '.') && ($nombreDir != '..') ){
						$ruta_real_carpeta = realpath($ruta_real . DIRECTORY_SEPARATOR . $nombreDir);
						$ruta_relativa_carpeta = str_replace(realpath(_WS_UPLOAD_IMAGES_DIR_), '', $ruta_real_carpeta);
						Theme::include_file($rutaFicheroUpDown, $ruta_actual . ($ruta_actual != '' ? DIRECTORY_SEPARATOR : '') . $nombreDir, $nombreDir, 'mdi mdi-folder-multiple', $ruta_relativa_carpeta);
					}
				}
			}
			if ($rutaFicheroCrearDirectorio != ''){
				//Por último, siempre vamos a crear la carpeta:
				Theme::include_file($rutaFicheroCrearDirectorio, $ruta_actual);
			}

			if ($rufaFichero != ''){
				$extensions = '{jpg,JPG,gif,GIF,png,PNG,bmp,BMP,svg,SVG}';
				//Vamos a recorrer la carpeta de imagenes
				$filtro = $ruta_real . '/*.' . $extensions;
				$images = glob($filtro, GLOB_BRACE);
				//var_dump($images);
				if ($images !== false){
					foreach($images as $kew => $value){
						$img_name = _WS_UPLOAD_IMAGES_DIR_ . $ruta_actual . (substr($ruta_actual,-1) != DIRECTORY_SEPARATOR ? DIRECTORY_SEPARATOR : '') . basename($value);
						Theme::include_file($rufaFichero, $img_name);
					}
				}
			}
		}else{
			
		}
		if ($script_x_defecto != ''){
?>
<script>
try {
 <?=$script_x_defecto;?>;
}
catch(err) {
}
</script>
<?php
		}
	?>
	</div>
	</div>
	<?php
}

?>
